window.Gleam.initSearch([{"doc":"morse_code_translator","title":"morse_code_translator","content":"# Morse Code Translator\n\n[![Package Version](https://img.shields.io/hexpm/v/morse_code_translator)](https://hex.pm/packages/morse_code_translator)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/morse_code_translator/)\n\n## Links\n\n* [Homepage](https://salif.github.io/morse-code-translator/)\n* [Source code](https://codeberg.org/salif/morse-code-translator)\n* [Discussions (Github)](https://github.com/salif/morse-code-translator/discussions)\n\n## Usage\n\n```sh\ngleam add morse_code_translator\n```\n\n```gleam\nimport gleam/io\nimport gleam/option.{None, Some}\nimport morse_code_translator as mct\n\npub fn main() {\n   let demo_encode_options =\n      mct.EncodeOptions(\n         output_dot: None,\n         output_dash: None,\n         output_space: None,\n         output_separator: None,\n         is_uppercase: None,\n         language_num: None,\n      )\n\n   let demo_decode_options =\n      mct.DecodeOptions(\n         input_dot: None,\n         input_dash: None,\n         input_space: None,\n         input_separator: None,\n         to_uppercase: None,\n         language_num: None,\n      )\n\n   let demo_encode: Result(String, mct.MorseCodeError) =\n      mct.encode(&quot; Test &quot;, demo_encode_options, None)\n   io.debug(demo_encode)\n   // Ok(&quot;/ - . ... - /&quot;)\n\n   let demo_decode: Result(String, mct.MorseCodeError) =\n      mct.decode(&quot;/ - . ... - /&quot;, demo_decode_options, None)\n   io.debug(demo_decode)\n   // Ok(&quot; test &quot;)\n\n   &quot;demo&quot;\n   |&gt; mct.encode_to_string(demo_encode_options, None)\n   |&gt; mct.decode_to_string(demo_decode_options, None)\n   |&gt; io.debug\n   // &quot;demo&quot;\n\n   &quot;_.. . __ ___&quot;\n   |&gt; mct.decode_to_string(\n      mct.DecodeOptions(\n         ..demo_decode_options,\n         input_dash: Some(&quot;_&quot;),\n         language_num: Some(mct.language_num_cyrillic),\n      ),\n      None,\n   )\n   |&gt; io.debug\n   // &quot;демо&quot;\n\n   let demo_convert_options =\n      mct.ConvertOptions(\n         input_dot: mct.default_dot,\n         output_dot: &quot;0&quot;,\n         input_dash: mct.default_dash,\n         output_dash: &quot;1&quot;,\n         input_space: mct.default_space,\n         output_space: mct.default_space,\n         input_separator: mct.default_separator,\n         output_separator: mct.default_separator,\n      )\n\n   &quot;-.. . -- ---&quot;\n   |&gt; mct.convert(demo_convert_options)\n   |&gt; io.debug\n   // Ok(&quot;100 0 11 111&quot;)\n\n   &quot;=&quot;\n   |&gt; mct.convert_to_string(demo_convert_options)\n   |&gt; io.debug\n   // &quot;Invalid morse code symbol: =&quot;\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/morse_code_translator&gt;.\n\n## Development\n\n```sh\njust build\n```\n","url":"index.html"},{"doc":"characters","title":"base_characters","content":"pub const base_characters: List(#(String, String, List(Bool)))\n\nSynonyms:\ncharacters.base_characters\ncharacters base_characters","url":"characters.html#base_characters"},{"doc":"characters","title":"characters","content":"","url":"characters.html"},{"doc":"morse_code_translator","title":"ConvertOptions","content":"pub type ConvertOptions {\n  ConvertOptions(\n    input_dot: String,\n    output_dot: String,\n    input_dash: String,\n    output_dash: String,\n    input_space: String,\n    output_space: String,\n    input_separator: String,\n    output_separator: String,\n  )\n}\n\nConvertOptions(\n  input_dot: String,\n  output_dot: String,\n  input_dash: String,\n  output_dash: String,\n  input_space: String,\n  output_space: String,\n  input_separator: String,\n  output_separator: String,\n)\n\n\nSynonyms:\nmorse_code_translator.ConvertOptions\nmorse_code_translator ConvertOptions","url":"morse_code_translator.html#ConvertOptions"},{"doc":"morse_code_translator","title":"DecodeOptions","content":"pub type DecodeOptions {\n  DecodeOptions(\n    input_dot: option.Option(String),\n    input_dash: option.Option(String),\n    input_space: option.Option(String),\n    input_separator: option.Option(String),\n    to_uppercase: option.Option(Bool),\n    language_num: option.Option(String),\n  )\n}\n\nDecodeOptions(\n  input_dot: option.Option(String),\n  input_dash: option.Option(String),\n  input_space: option.Option(String),\n  input_separator: option.Option(String),\n  to_uppercase: option.Option(Bool),\n  language_num: option.Option(String),\n)\n\n\nSynonyms:\nmorse_code_translator.DecodeOptions\nmorse_code_translator DecodeOptions","url":"morse_code_translator.html#DecodeOptions"},{"doc":"morse_code_translator","title":"EncodeOptions","content":"pub type EncodeOptions {\n  EncodeOptions(\n    output_dot: option.Option(String),\n    output_dash: option.Option(String),\n    output_space: option.Option(String),\n    output_separator: option.Option(String),\n    is_uppercase: option.Option(Bool),\n    language_num: option.Option(String),\n  )\n}\n\nEncodeOptions(\n  output_dot: option.Option(String),\n  output_dash: option.Option(String),\n  output_space: option.Option(String),\n  output_separator: option.Option(String),\n  is_uppercase: option.Option(Bool),\n  language_num: option.Option(String),\n)\n\n\nSynonyms:\nmorse_code_translator.EncodeOptions\nmorse_code_translator EncodeOptions","url":"morse_code_translator.html#EncodeOptions"},{"doc":"morse_code_translator","title":"MorseCodeError","content":"pub type MorseCodeError {\n  MorseCodeError(msg: String)\n}\n\nMorseCodeError(msg: String)\n\n\nSynonyms:\nmorse_code_translator.MorseCodeError\nmorse_code_translator MorseCodeError","url":"morse_code_translator.html#MorseCodeError"},{"doc":"morse_code_translator","title":"MorseCodeList","content":"pub type MorseCodeList =\n  List(#(String, String, List(Bool)))\n\n\nSynonyms:\nmorse_code_translator.MorseCodeList\nmorse_code_translator MorseCodeList","url":"morse_code_translator.html#MorseCodeList"},{"doc":"morse_code_translator","title":"default_dash","content":"pub const default_dash: String\n\nSynonyms:\nmorse_code_translator.default_dash\nmorse_code_translator default_dash","url":"morse_code_translator.html#default_dash"},{"doc":"morse_code_translator","title":"default_dot","content":"pub const default_dot: String\n\nSynonyms:\nmorse_code_translator.default_dot\nmorse_code_translator default_dot","url":"morse_code_translator.html#default_dot"},{"doc":"morse_code_translator","title":"default_is_uppercase","content":"pub const default_is_uppercase: Bool\n\nSynonyms:\nmorse_code_translator.default_is_uppercase\nmorse_code_translator default_is_uppercase","url":"morse_code_translator.html#default_is_uppercase"},{"doc":"morse_code_translator","title":"default_language_num","content":"pub const default_language_num: String\n\nSynonyms:\nmorse_code_translator.default_language_num\nmorse_code_translator default_language_num","url":"morse_code_translator.html#default_language_num"},{"doc":"morse_code_translator","title":"default_separator","content":"pub const default_separator: String\n\nSynonyms:\nmorse_code_translator.default_separator\nmorse_code_translator default_separator","url":"morse_code_translator.html#default_separator"},{"doc":"morse_code_translator","title":"default_space","content":"pub const default_space: String\n\nSynonyms:\nmorse_code_translator.default_space\nmorse_code_translator default_space","url":"morse_code_translator.html#default_space"},{"doc":"morse_code_translator","title":"default_to_uppercase","content":"pub const default_to_uppercase: Bool\n\nSynonyms:\nmorse_code_translator.default_to_uppercase\nmorse_code_translator default_to_uppercase","url":"morse_code_translator.html#default_to_uppercase"},{"doc":"morse_code_translator","title":"language_num_arabic","content":"pub const language_num_arabic: String\n\nSynonyms:\nmorse_code_translator.language_num_arabic\nmorse_code_translator language_num_arabic","url":"morse_code_translator.html#language_num_arabic"},{"doc":"morse_code_translator","title":"language_num_cyrillic","content":"pub const language_num_cyrillic: String\n\nSynonyms:\nmorse_code_translator.language_num_cyrillic\nmorse_code_translator language_num_cyrillic","url":"morse_code_translator.html#language_num_cyrillic"},{"doc":"morse_code_translator","title":"language_num_greek","content":"pub const language_num_greek: String\n\nSynonyms:\nmorse_code_translator.language_num_greek\nmorse_code_translator language_num_greek","url":"morse_code_translator.html#language_num_greek"},{"doc":"morse_code_translator","title":"language_num_hebrew","content":"pub const language_num_hebrew: String\n\nSynonyms:\nmorse_code_translator.language_num_hebrew\nmorse_code_translator language_num_hebrew","url":"morse_code_translator.html#language_num_hebrew"},{"doc":"morse_code_translator","title":"language_num_japanese","content":"pub const language_num_japanese: String\n\nSynonyms:\nmorse_code_translator.language_num_japanese\nmorse_code_translator language_num_japanese","url":"morse_code_translator.html#language_num_japanese"},{"doc":"morse_code_translator","title":"language_num_korean","content":"pub const language_num_korean: String\n\nSynonyms:\nmorse_code_translator.language_num_korean\nmorse_code_translator language_num_korean","url":"morse_code_translator.html#language_num_korean"},{"doc":"morse_code_translator","title":"language_num_latin","content":"pub const language_num_latin: String\n\nSynonyms:\nmorse_code_translator.language_num_latin\nmorse_code_translator language_num_latin","url":"morse_code_translator.html#language_num_latin"},{"doc":"morse_code_translator","title":"language_num_latin_extended","content":"pub const language_num_latin_extended: String\n\nSynonyms:\nmorse_code_translator.language_num_latin_extended\nmorse_code_translator language_num_latin_extended","url":"morse_code_translator.html#language_num_latin_extended"},{"doc":"morse_code_translator","title":"language_num_numbers","content":"pub const language_num_numbers: String\n\nSynonyms:\nmorse_code_translator.language_num_numbers\nmorse_code_translator language_num_numbers","url":"morse_code_translator.html#language_num_numbers"},{"doc":"morse_code_translator","title":"language_num_persian","content":"pub const language_num_persian: String\n\nSynonyms:\nmorse_code_translator.language_num_persian\nmorse_code_translator language_num_persian","url":"morse_code_translator.html#language_num_persian"},{"doc":"morse_code_translator","title":"language_num_punctuation","content":"pub const language_num_punctuation: String\n\nSynonyms:\nmorse_code_translator.language_num_punctuation\nmorse_code_translator language_num_punctuation","url":"morse_code_translator.html#language_num_punctuation"},{"doc":"morse_code_translator","title":"language_num_thai","content":"pub const language_num_thai: String\n\nSynonyms:\nmorse_code_translator.language_num_thai\nmorse_code_translator language_num_thai","url":"morse_code_translator.html#language_num_thai"},{"doc":"morse_code_translator","title":"morse_code_list","content":"pub const morse_code_list: List(#(String, String, List(Bool)))\n\nSynonyms:\nmorse_code_translator.morse_code_list\nmorse_code_translator morse_code_list","url":"morse_code_translator.html#morse_code_list"},{"doc":"morse_code_translator","title":"convert","content":"pub fn convert(\n  input: String,\n  options: ConvertOptions,\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.convert\nmorse_code_translator convert","url":"morse_code_translator.html#convert"},{"doc":"morse_code_translator","title":"convert_to_string","content":"pub fn convert_to_string(\n  input: String,\n  options: ConvertOptions,\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.convert_to_string\nmorse_code_translator convert_to_string","url":"morse_code_translator.html#convert_to_string"},{"doc":"morse_code_translator","title":"decode","content":"pub fn decode(\n  input: String,\n  options: DecodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.decode\nmorse_code_translator decode","url":"morse_code_translator.html#decode"},{"doc":"morse_code_translator","title":"decode_to_string","content":"pub fn decode_to_string(\n  input: String,\n  options: DecodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.decode_to_string\nmorse_code_translator decode_to_string","url":"morse_code_translator.html#decode_to_string"},{"doc":"morse_code_translator","title":"encode","content":"pub fn encode(\n  input: String,\n  options: EncodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; Result(String, MorseCodeError)\n\nSynonyms:\nmorse_code_translator.encode\nmorse_code_translator encode","url":"morse_code_translator.html#encode"},{"doc":"morse_code_translator","title":"encode_to_string","content":"pub fn encode_to_string(\n  input: String,\n  options: EncodeOptions,\n  morse_code_dict: Option(List(#(String, String, List(Bool)))),\n) -&gt; String\n\nSynonyms:\nmorse_code_translator.encode_to_string\nmorse_code_translator encode_to_string","url":"morse_code_translator.html#encode_to_string"},{"doc":"morse_code_translator","title":"morse_code_translator","content":"","url":"morse_code_translator.html"}]);